=== modified file 'multiparent/__init__.py'
--- multiparent/__init__.py	2007-04-10 17:07:59 +0000
+++ multiparent/__init__.py	2007-04-11 00:16:09 +0000
@@ -120,3 +120,25 @@
     def to_patch(self):
         yield 'c %(parent)d %(parent_pos)d %(child_pos)d %(num_lines)d\n'\
             % self.__dict__
+
+
+class MultiVersionedFile(object):
+
+    def __init__(self):
+        self._diffs = {}
+        self._lines = {}
+        self._parents = {}
+
+    def add_version(self, lines, version_id, parent_ids):
+        parent_lines = [self._lines[p] for p in parent_ids]
+        diff = MultiParent.from_lines(lines, parent_lines)
+        self.add_diff(diff, version_id, parent_ids)
+        self._lines[version_id] = lines
+
+    def add_diff(self, diff, version_id, parent_ids):
+        self._diffs[version_id] = diff
+        self._parents[version_id] = parent_ids
+
+    def clear_cache(self):
+        self._lines.clear()
+        pass

=== renamed directory 'tests' => 'multiparent/tests'
=== modified file 'multiparent/tests/test_multiparent.py'
--- tests/test_multiparent.py	2007-04-10 16:54:51 +0000
+++ multiparent/tests/test_multiparent.py	2007-04-11 00:16:09 +0000
@@ -84,3 +84,16 @@
     def test_to_patch(self):
         self.assertEqual(['c 0 1 2 3\n'],
                          list(multiparent.ParentText(0, 1, 2, 3).to_patch()))
+
+
+class TestVersionedFile(TestCase):
+
+    def add_version(self, vf, text, version_id, parent_ids):
+        vf.add_version([(t+'\n') for t in text], version_id, parent_ids)
+
+    def test_add_version(self):
+        vf = multiparent.MultiVersionedFile()
+        self.add_version(vf, 'abcd', 'rev-a', [])
+        self.assertEqual(vf._lines['rev-a'], ['a\n', 'b\n', 'c\n', 'd\n'])
+        vf.clear_cache()
+        self.assertEqual(vf._lines, {})

